# Step 5: Plan Transformations and Create a Roadmap
### On this page
  * [Create and Structure Your Initiatives](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap#create-and-structure-your-initiatives)
  * [Add Key Milestones and Set the Lifecycle](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap#add-key-milestones-and-set-the-lifecycle)
  * [Create Transformations](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap#create-transformations)
  * [Create a Roadmap](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap#create-a-roadmap)


After evaluating which applications are best suited for modernization, it's time to plan your initiatives. This involves documenting your decisions, setting up your transformations, and creating a roadmap.
